"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _serverlessHttp = _interopRequireDefault(require("serverless-http"));

var _util = require("./util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let requestHandler;
/**
 * Next serverless request handler
 *
 * @param {object} app - Next.js app object
 * @param {function} handler - Request handler function
 * @param {function} runLocal - Function to run when the server is started locally
 * @return {function} A lambda request handler
 */

var _default = (app, handler, runLocal) => {
  // start local server when not in a lambda environment
  if (!(0, _util.isLambda)()) {
    return app.prepare().then(runLocal);
  } // handle api gateway requests in a lambda environment


  return (...gatewayParams) => {
    if (requestHandler) {
      return requestHandler(...gatewayParams);
    } // on first start, initially prepare the next.js app before handling requests


    app.prepare().then(() => {
      requestHandler = (0, _serverlessHttp.default)(handler);
      requestHandler(...gatewayParams);
    });
  };
};

exports.default = _default;